# Processamento-imagem

Description. 
The package Processamento-imagem is used to:
	Processamento:
		- Medir similaridade entre imagens
		- Transferir histogramas de uma imagem a outra
		- Redimensionar imagens
	Utils:
		- Ler imagens
		- Salvar imagens
		- Plotar imagens
		- Plotar resultados
		- Plotar histogramas

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install Rilton-processamento-imagem
```


## Author
Rilton Monte
